mlbench-core: Distributed Machine Learning Benchmark Core Library
=================================================================

[![Build Status](https://travis-ci.com/mlbench/mlbench-core.svg?branch=develop)](https://travis-ci.com/mlbench/mlbench-core)
[![DocumentationStatus](https://readthedocs.org/projects/mlbench-docs/badge/?version=latest)](https://mlbench.readthedocs.io/projects/mlbench_core/en/latest/api.html?badge=latest)

MLBench is a Benchmarking Framework for Distributed Machine Learning algorithms.

This repository contains the core Python library for MLBench which is used to share code between Benchmark implementations as well as for communication with the dashboard.

For more information refer to the [MLBench Core Documentation](https://mlbench.readthedocs.io/projects/mlbench_core/en/stable/api.html)
or the [Main Documentation](https://mlbench.readthedocs.io/)
